@@ -4,12 +4,11 @@
 ##################################################################
 
 import logging
-
 import os
 
 from lxml.builder import ElementMaker
 
-__version__ = "4.5.2"
+__version__ = "4.6.0"
 
 LOGGER = logging.getLogger('PYWPS')
 LOGGER.debug('setting core variables')
@@ -90,10 +89,10 @@ OGCUNIT = {
 
 from pywps.app import Process, Service, WPSRequest
 from pywps.app.WPSRequest import get_inputs_from_xml, get_output_from_xml
-from pywps.inout.inputs import LiteralInput, ComplexInput, BoundingBoxInput
-from pywps.inout.outputs import LiteralOutput, ComplexOutput, BoundingBoxOutput
-from pywps.inout.formats import Format, FORMATS, get_format
 from pywps.inout import UOM
+from pywps.inout.formats import FORMATS, Format, get_format
+from pywps.inout.inputs import BoundingBoxInput, ComplexInput, LiteralInput
+from pywps.inout.outputs import BoundingBoxOutput, ComplexOutput, LiteralOutput
 
 if __name__ == "__main__":
     pass
