@@ -3,30 +3,31 @@
 # licensed under MIT, Please consult LICENSE.txt for details     #
 ##################################################################
 
+import importlib
+import json
 import logging
 import os
-from pywps.translations import lower_case_dict
+import shutil
 import sys
 import traceback
-import json
-import shutil
 
-from pywps import dblog
-from pywps.response import get_response
-from pywps.response.status import WPS_STATUS
-from pywps.response.execute import ExecuteResponse
-from pywps.app.WPSRequest import WPSRequest
-from pywps.inout.inputs import input_from_json
-from pywps.inout.outputs import output_from_json
 import pywps.configuration as config
-from pywps.exceptions import (StorageNotSupported, OperationNotSupported,
-                              ServerBusy, NoApplicableCode,
-                              InvalidParameterValue)
+from pywps import dblog
 from pywps.app.exceptions import ProcessError
-from pywps.inout.storage.builder import StorageBuilder
+from pywps.app.WPSRequest import WPSRequest
+from pywps.exceptions import (
+    InvalidParameterValue,
+    NoApplicableCode,
+    OperationNotSupported,
+    ServerBusy,
+    StorageNotSupported,
+)
 from pywps.inout.outputs import ComplexOutput
-import importlib
-
+from pywps.inout.storage.builder import StorageBuilder
+from pywps.response import get_response
+from pywps.response.execute import ExecuteResponse
+from pywps.response.status import WPS_STATUS
+from pywps.translations import lower_case_dict
 
 LOGGER = logging.getLogger("PYWPS")
 
@@ -38,7 +39,7 @@ class Process(object):
                     :class:`pywps.app.WPSRequest` argument and return a
                     :class:`pywps.app.WPSResponse` object.
     :param string identifier: Name of this process.
-    :param string title: Human readable title of process.
+    :param string title: Human-readable title of process.
     :param string abstract: Brief narrative description of the process.
     :param list keywords: Keywords that characterize a process.
     :param inputs: List of inputs accepted by this process. They
@@ -56,19 +57,19 @@ class Process(object):
         e.g. {"fr-CA": {"title": "Mon titre", "abstract": "Une description"}}
     """
 
-    def __init__(self, handler, identifier, title, abstract='', keywords=[], profile=[],
-                 metadata=[], inputs=[], outputs=[], version='None', store_supported=False,
+    def __init__(self, handler, identifier, title, abstract='', keywords=None, profile=None,
+                 metadata=None, inputs=None, outputs=None, version='None', store_supported=False,
                  status_supported=False, grass_location=None, translations=None):
         self.identifier = identifier
         self.handler = handler
         self.title = title
         self.abstract = abstract
-        self.keywords = keywords
-        self.metadata = metadata
-        self.profile = profile
+        self.keywords = keywords if keywords is not None else []
+        self.metadata = metadata if metadata is not None else []
+        self.profile = profile if profile is not None else []
         self.version = version
-        self.inputs = inputs
-        self.outputs = outputs
+        self.inputs = inputs if inputs is not None else []
+        self.outputs = outputs if outputs is not None else []
         self.uuid = None
         self._status_store = None
         # self.status_location = ''
@@ -183,7 +184,9 @@ class Process(object):
         return self.status_store.url(self.status_filename)
 
     def _execute_process(self, async_, wps_request, wps_response):
-        """Uses :module:`pywps.processing` module for sending process to
+        """
+
+        Uses :module:`pywps.processing` module for sending process to
         background BUT first, check for maxprocesses configuration value
 
         :param async_: run in asynchronous mode
@@ -194,6 +197,11 @@ class Process(object):
 
         running, stored = dblog.get_process_counts()
 
+        if maxparallel != -1 and running >= maxparallel:
+            # Try to check for crashed process
+            dblog.cleanup_crashed_process()
+            running, stored = dblog.get_process_counts()
+
         # async
         if async_:
 
@@ -217,7 +225,7 @@ class Process(object):
 
         # not async
         else:
-            if running >= maxparallel and maxparallel != -1:
+            if running >= maxparallel != -1:
                 raise ServerBusy('Maximum number of parallel running processes reached. Please try later.')
             wps_response._update_status(WPS_STATUS.ACCEPTED, "PyWPS Request accepted", 0)
             wps_response = self._run_process(wps_request, wps_response)
@@ -238,7 +246,9 @@ class Process(object):
     # This function may not raise exception and must return a valid wps_response
     # Failure must be reported as wps_response.status = WPS_STATUS.FAILED
     def _run_process(self, wps_request, wps_response):
-        LOGGER.debug("Started processing request: {}".format(self.uuid))
+        LOGGER.debug("Started processing request: {} with pid: {}".format(self.uuid, os.getpid()))
+        # Update the actual pid of current process to check if failed latter
+        dblog.update_pid(self.uuid, os.getpid())
         try:
             self._set_grass(wps_request)
             # if required set HOME to the current working directory.
@@ -350,27 +360,25 @@ class Process(object):
             outpt.workdir = workdir
 
     def _set_grass(self, wps_request):
-        """Handle given grass_location parameter of the constructor
+        """Handle given grass_location parameter of the constructor.
 
-        location is either directory name, 'epsg:1234' form or a georeferenced
-        file
+        location is either directory name, 'epsg:1234' form or a geo-referenced file.
 
-        in the first case, new temporary mapset within the location will be
-        created
+        In the first case, new temporary mapset within the location will be created.
 
-        in the second case, location will be created in self.workdir
+        In the second case, location will be created in self.workdir.
 
-        the mapset should be deleted automatically using self.clean() method
+        The mapset should be deleted automatically using self.clean() method
         """
         if self.grass_location:
 
             import random
             import string
+
             from grass.script import core as grass
             from grass.script import setup as gsetup
 
-            # HOME needs to be set - and that is usually not the case for httpd
-            # server
+            # HOME needs to be set - and that is usually not the case for httpd server
             os.environ['HOME'] = self.workdir
 
             # GISRC envvariable needs to be set
@@ -436,8 +444,10 @@ class Process(object):
                 grass.run_command('g.gisenv', set="MAPSET=%s" % mapset_name)
 
             else:
+                # FIXME: This will fail as location is not set.
                 raise NoApplicableCode('Location does exists or does not seem '
-                                       'to be in "EPSG:XXXX" form nor is it existing directory: {}'.format(location))
+                                       'to be in "EPSG:XXXX" form nor is it existing directory: '
+                                       '{}'.format(location))
 
             # set _grass_mapset attribute - will be deleted once handler ends
             self._grass_mapset = mapset_name
