@@ -3,37 +3,39 @@
 # licensed under MIT, Please consult LICENSE.txt for details     #
 ##################################################################
 
+import copy
 import logging
-import tempfile
-from typing import Sequence, Optional, Dict
-
-from werkzeug.exceptions import HTTPException
-from werkzeug.wrappers import Request, Response
-from urllib.parse import urlparse
-from pywps.app.WPSRequest import WPSRequest
-import pywps.configuration as config
-from pywps.exceptions import MissingParameterValue, NoApplicableCode, InvalidParameterValue, FileSizeExceeded, \
-    StorageNotSupported, FileURLNotSupported
-from pywps.inout.inputs import ComplexInput, LiteralInput, BoundingBoxInput
-from pywps.dblog import log_request, store_status
-from pywps import response
-from pywps.response.status import WPS_STATUS
-
-from collections import deque, OrderedDict
 import os
 import sys
+import tempfile
 import uuid
-import copy
-import shutil
+from collections import OrderedDict, deque
+from typing import Dict, Optional, Sequence
+from urllib.parse import urlparse
 
+from werkzeug.exceptions import HTTPException
+from werkzeug.wrappers import Request
+
+import pywps.configuration as config
+from pywps import response
+from pywps.app.WPSRequest import WPSRequest
+from pywps.dblog import log_request, store_status
+from pywps.exceptions import (
+    FileURLNotSupported,
+    InvalidParameterValue,
+    MissingParameterValue,
+    NoApplicableCode,
+)
+from pywps.inout.inputs import BoundingBoxInput, ComplexInput, LiteralInput
+from pywps.response.status import WPS_STATUS
 
 LOGGER = logging.getLogger("PYWPS")
 
 
 class Service(object):
+    """The top-level object that represents a WPS service.
 
-    """ The top-level object that represents a WPS service. It's a WSGI
-    application.
+    A WSGI application.
 
     :param processes: A list of :class:`~Process` objects that are
                       provided by this service.
