@@ -7,13 +7,13 @@
 Reads the PyWPS configuration file
 """
 
-import logging
-import sys
-import os
-import tempfile
-import pywps
-
 import configparser
+import logging
+import os
+import sys
+import tempfile
+
+import pywps
 
 __author__ = "Calin Ciociu"
 
@@ -27,6 +27,36 @@ LOGGER = logging.getLogger("PYWPS")
 wps_strict = True
 
 
+class EnvInterpolation(configparser.BasicInterpolation):
+    """
+    Configuration parser class to allow env variable interpolation.
+
+    With this interpolator it is possible to use env variables as
+    part of the values in an cfg file.
+
+    Example (given an env variable HOSTNAME=localhost):
+
+    [server]
+    url = http://${HOSTNAME}/wps
+
+
+    ==> http://localhost/wps
+
+
+    This code is an adaption from the configuation parsing in the pycsw
+    project.
+    See also
+    - https://github.com/geopython/pycsw/blob/3.0.0-alpha3/pycsw/core/util.py
+    - https://stackoverflow.com/a/49529659
+
+    """
+
+    def before_get(self, parser, section, option, value, defaults):
+        """Expand env variables when returning values."""
+        value = super().before_get(parser, section, option, value, defaults)
+        return os.path.expandvars(value)
+
+
 def get_config_value(section, option, default_value=''):
     """Get desired value from  configuration files
 
@@ -34,6 +64,8 @@ def get_config_value(section, option, default_value=''):
     :type section: string
     :param option: option in the section
     :type option: string
+    :param default_value: default value for configuration
+    :type default_value: string
     :returns: value found in the configuration file
     """
 
@@ -56,20 +88,16 @@ def get_config_value(section, option, default_value=''):
     return value
 
 
-def load_configuration(cfgfiles=None):
-    """Load PyWPS configuration from configuration files.
-    The later configuration file in the array overwrites configuration
-    from the first.
-
-    :param cfgfiles: list of configuration files
-    """
+def load_hardcoded_configuration():
+    """Load PyWPS hardcoded configuration."""
 
     global CONFIG
 
-    LOGGER.info('loading configuration')
-    CONFIG = configparser.ConfigParser(os.environ)
+    LOGGER.debug('loading harcoded configuration')
+    CONFIG = configparser.ConfigParser(os.environ, interpolation=EnvInterpolation())
+
+    tmpdir = tempfile.gettempdir()
 
-    LOGGER.debug('setting default values')
     CONFIG.add_section('server')
     CONFIG.set('server', 'encoding', 'utf-8')
     CONFIG.set('server', 'language', 'en-US')
@@ -77,38 +105,23 @@ def load_configuration(cfgfiles=None):
     CONFIG.set('server', 'maxprocesses', '30')
     CONFIG.set('server', 'maxsingleinputsize', '1mb')
     CONFIG.set('server', 'maxrequestsize', '3mb')
-    CONFIG.set('server', 'temp_path', tempfile.gettempdir())
+    CONFIG.set('server', 'temp_path', tmpdir)
     CONFIG.set('server', 'processes_path', '')
-    outputpath = tempfile.gettempdir()
-    CONFIG.set('server', 'outputurl', file_uri(outputpath))
-    CONFIG.set('server', 'outputpath', outputpath)
-    # list of allowed input paths (file url input) seperated by ':'
+    CONFIG.set('server', 'outputurl', file_uri(tmpdir))
+    CONFIG.set('server', 'outputpath', tmpdir)
     CONFIG.set('server', 'allowedinputpaths', '')
-    CONFIG.set('server', 'workdir', tempfile.gettempdir())
+    CONFIG.set('server', 'workdir', tmpdir)
     CONFIG.set('server', 'parallelprocesses', '2')
-    # If this flag is enabled it will set the HOME environment
-    # for each process to its current workdir (a temp folder).
     CONFIG.set('server', 'sethomedir', 'false')
-    # If this flag is enabled PyWPS will remove the process temporary workdir
-    # after process has finished.
     CONFIG.set('server', 'cleantempdir', 'true')
     CONFIG.set('server', 'storagetype', 'file')
-    # File storage outputs can be copied, moved or linked
-    # from the workdir to the output folder.
-    # Allowed functions: "copy", "move", "link" (default "copy")
     CONFIG.set('server', 'storage_copy_function', 'copy')
-
-    # handles the default mimetype for requests.
-    # available options: "text/xml", "application/json"
     CONFIG.set("server", "default_mimetype", "text/xml")
-
-    # default json indentation for responses.
     CONFIG.set("server", "json_indent", "2")
 
     CONFIG.add_section('processing')
     CONFIG.set('processing', 'mode', 'default')
     CONFIG.set('processing', 'path', os.path.dirname(os.path.realpath(sys.argv[0])))
-    # https://github.com/natefoo/slurm-drmaa
     CONFIG.set('processing', 'drmaa_native_specification', '')
 
     CONFIG.add_section('logging')
@@ -152,6 +165,20 @@ def load_configuration(cfgfiles=None):
     CONFIG.set('s3', 'encrypt', 'false')
     CONFIG.set('s3', 'region', '')
 
+
+def load_configuration(cfgfiles=None):
+    """Load PyWPS configuration from configuration files.
+
+    The later configuration file in the array overwrites configuration
+    from the first.
+
+    :param cfgfiles: list of configuration files
+    """
+
+    global CONFIG
+
+    load_hardcoded_configuration()
+
     if not cfgfiles:
         cfgfiles = _get_default_config_files_location()
 
@@ -191,15 +218,17 @@ def _check_config():
 
 
 def _get_default_config_files_location():
-    """Get the locations of the standard configuration files. These are
+    """Get the locations of the standard configuration files.
+
+    These are:
     Unix/Linux:
         1. `/etc/pywps.cfg`
         2. `$HOME/.pywps.cfg`
     Windows:
         1. `pywps\\etc\\default.cfg`
-
     Both:
         1. `$PYWPS_CFG environment variable`
+
     :returns: configuration files
     :rtype: list of strings
     """
