@@ -3,26 +3,25 @@
 # licensed under MIT, Please consult LICENSE.txt for details     #
 ##################################################################
 
-"""Validator classes are used for ComplexInputs, to validate the content
-"""
+"""Validator classes are used for ComplexInputs, to validate the content"""
 
 
 import logging
-
-from pywps.validator.mode import MODE
-from pywps.inout.formats import FORMATS
-from lxml.etree import XMLSchema
-from pywps import xml_util as etree
-from urllib.request import urlopen
 import mimetypes
 import os
+from urllib.request import urlopen
 
+from lxml.etree import XMLSchema
+
+from pywps import xml_util as etree
+from pywps.inout.formats import FORMATS
+from pywps.validator.mode import MODE
 
 LOGGER = logging.getLogger('PYWPS')
 
 
 def validategml(data_input, mode):
-    """GML validation function
+    """GML validation function.
 
     :param data_input: :class:`ComplexInput`
     :param pywps.validator.mode.MODE mode:
@@ -76,7 +75,7 @@ def validategml(data_input, mode):
 
 
 def validategpx(data_input, mode):
-    """GPX validation function
+    """GPX validation function.
 
     :param data_input: :class:`ComplexInput`
     :param pywps.validator.mode.MODE mode:
@@ -130,7 +129,7 @@ def validategpx(data_input, mode):
 
 
 def validatexml(data_input, mode):
-    """XML validation function
+    """XML validation function.
 
     :param data_input: :class:`ComplexInput`
     :param pywps.validator.mode.MODE mode:
@@ -176,7 +175,7 @@ def validatexml(data_input, mode):
 
 
 def validatejson(data_input, mode):
-    """JSON validation function
+    """JSON validation function.
 
     :param data_input: :class:`ComplexInput`
     :param pywps.validator.mode.MODE mode:
@@ -221,16 +220,16 @@ def validatejson(data_input, mode):
 def validategeojson(data_input, mode):
     """GeoJSON validation example
 
-    >>> import StringIO
+    >>> from io import StringIO
     >>> class FakeInput(object):
     ...     json = open('point.geojson','w')
     ...     json.write('''{"type":"Feature", "properties":{}, "geometry":{"type":"Point", "coordinates":[8.5781228542328, 22.87500500679]}, "crs":{"type":"name", "properties":{"name":"urn:ogc:def:crs:OGC:1.3:CRS84"}}}''')  # noqa
     ...     json.close()
     ...     file = 'point.geojson'
-    >>> class fake_data_format(object):
+    >>> class FakeDataFormat(object):
     ...     mimetype = 'application/geojson'
     >>> fake_input = FakeInput()
-    >>> fake_input.data_format = fake_data_format()
+    >>> fake_input.data_format = FakeDataFormat()
     >>> validategeojson(fake_input, MODE.SIMPLE)
     True
     """
@@ -258,37 +257,25 @@ def validategeojson(data_input, mode):
 
     if mode >= MODE.VERYSTRICT:
 
-        import jsonschema
         import json
 
+        import jsonschema
+        import referencing
+
         # this code comes from
         # https://github.com/om-henners/GeoJSON_Validation/blob/master/geojsonvalidation/geojson_validation.py
+        schema_uri = "http://json-schema.org/geojson"
         schema_home = os.path.join(_get_schemas_home(), "geojson")
-        base_schema = os.path.join(schema_home, "geojson.json")
 
-        with open(base_schema) as fh:
-            geojson_base = json.load(fh)
+        registry = referencing.Registry()
 
-        with open(os.path.join(schema_home, "crs.json")) as fh:
-            crs_json = json.load(fh)
+        for fn in ["geojson.json", "crs.json", "bbox.json", "geometry.json"]:
+            with open(os.path.join(schema_home, fn)) as fh:
+                schema_data = json.load(fh)
+                registry = registry.with_resource(f"{schema_uri}/{fn}",
+                                                  referencing.Resource(schema_data, referencing.jsonschema.DRAFT4))
 
-        with open(os.path.join(schema_home, "bbox.json")) as fh:
-            bbox_json = json.load(fh)
-
-        with open(os.path.join(schema_home, "geometry.json")) as fh:
-            geometry_json = json.load(fh)
-
-        cached_json = {
-            "http://json-schema.org/geojson/crs.json": crs_json,
-            "http://json-schema.org/geojson/bbox.json": bbox_json,
-            "http://json-schema.org/geojson/geometry.json": geometry_json
-        }
-
-        resolver = jsonschema.RefResolver(
-            "http://json-schema.org/geojson/geojson.json",
-            geojson_base, store=cached_json)
-
-        validator = jsonschema.Draft4Validator(geojson_base, resolver=resolver)
+        validator = jsonschema.Draft4Validator({"$ref": f"{schema_uri}/geojson.json"}, registry=registry)
         try:
             validator.validate(json.loads(data_input.stream.read()))
             passed = True
@@ -299,9 +286,7 @@ def validategeojson(data_input, mode):
 
 
 def validateshapefile(data_input, mode):
-    """ESRI Shapefile validation example
-
-    """
+    """ESRI Shapefile validation example."""
 
     LOGGER.info('validating Shapefile; Mode: {}'.format(mode))
     passed = False
@@ -328,8 +313,7 @@ def validateshapefile(data_input, mode):
 
 
 def validategeotiff(data_input, mode):
-    """GeoTIFF validation example
-    """
+    """GeoTIFF validation example."""
 
     LOGGER.info('Validating Shapefile; Mode: {}'.format(mode))
     passed = False
@@ -347,6 +331,7 @@ def validategeotiff(data_input, mode):
 
         try:
             from geotiff import GeoTiff
+
             data_source = GeoTiff(data_input.file)
             passed = (data_source.crs_code > 0)
         except (ModuleNotFoundError, ImportError):
@@ -356,8 +341,7 @@ def validategeotiff(data_input, mode):
 
 
 def validatenetcdf(data_input, mode):
-    """netCDF validation.
-    """
+    """NetCDF validation."""
 
     LOGGER.info('Validating netCDF; Mode: {}'.format(mode))
     passed = False
@@ -388,8 +372,7 @@ def validatenetcdf(data_input, mode):
 
 
 def validatedods(data_input, mode):
-    """OPeNDAP validation.
-        """
+    """OPeNDAP validation."""
 
     LOGGER.info('Validating OPeNDAP; Mode: {}'.format(mode))
     passed = False
@@ -419,8 +402,7 @@ def validatedods(data_input, mode):
 
 
 def _get_schemas_home():
-    """Get path to schemas directory
-    """
+    """Get path to schemas directory."""
     schema_dir = os.path.join(
         os.path.abspath(
             os.path.dirname(__file__)
