@@ -3,13 +3,15 @@
 # licensed under MIT, Please consult LICENSE.txt for details     #
 ##################################################################
 
-import unittest
+from basic import TestBase
+
 import pytest
 from collections import namedtuple
 from pywps import Process, Service, LiteralInput, ComplexInput, BoundingBoxInput
 from pywps import LiteralOutput, ComplexOutput, BoundingBoxOutput
 from pywps import get_ElementMakerForVersion, OGCTYPE, Format, NAMESPACES, OGCUNIT
 from pywps.inout.literaltypes import LITERAL_DATA_TYPES
+from pywps.inout.basic import UOM
 from pywps.app.basic import get_xpath_ns
 from pywps.app.Common import Metadata
 from pywps.inout.literaltypes import AllowedValue
@@ -38,6 +40,25 @@ def get_default_value(el):
     return default
 
 
+def get_single_uom(el):
+    ows = el.nsmap["ows"]
+    unit = el.text
+    href = el.attrib.get(f"{{{ows}}}reference")
+    return {"uom": unit, "reference": href}
+
+
+def get_supported_uoms(el):
+    uoms = xpath_ns(el, './UOMs')
+    if not uoms:
+        return None
+    uom_default = xpath_ns(uoms[0], './Default')[0]
+    uom_support = xpath_ns(uoms[0], './Supported')[0]
+    return {
+        "default": get_single_uom(xpath_ns(uom_default, './ows:UOM')[0]),
+        "supported": [get_single_uom(uom) for uom in xpath_ns(uom_support, './ows:UOM')]
+    }
+
+
 xpath_ns = get_xpath_ns("1.0.0")
 
 
@@ -61,7 +82,8 @@ def get_describe_result(resp):
                 [data_type_el] = xpath_ns(literal_data_el, './ows:DataType')
                 default = get_default_value(literal_data_el)
                 data_type = get_data_type(data_type_el)
-                inputs.append((input_identifier, 'literal', data_type, default))
+                uoms = get_supported_uoms(literal_data_el)
+                inputs.append((input_identifier, 'literal', data_type, default, uoms))
             elif complex_data_el_list:
                 [complex_data_el] = complex_data_el_list
                 formats = []
@@ -76,9 +98,11 @@ def get_describe_result(resp):
     return result
 
 
-class DescribeProcessTest(unittest.TestCase):
+class DescribeProcessTest(TestBase):
 
     def setUp(self):
+        super().setUp()
+
         def hello(request):
             pass
 
@@ -139,9 +163,11 @@ class DescribeProcessTest(unittest.TestCase):
         assert [pr.identifier for pr in result] == ['hello', 'ping']
 
 
-class DescribeProcessTranslationsTest(unittest.TestCase):
+class DescribeProcessTranslationsTest(TestBase):
 
     def setUp(self):
+        super().setUp()
+
         configuration.get_config_value('server', 'language')
         configuration.CONFIG.set('server', 'language', 'en-US,fr-CA')
         self.client = client_for(
@@ -197,9 +223,6 @@ class DescribeProcessTranslationsTest(unittest.TestCase):
             )
         )
 
-    def tearDown(self):
-        configuration.CONFIG.set('server', 'language', 'en-US')
-
     def test_get_describe_translations(self):
         resp = self.client.get('?Request=DescribeProcess&service=wps&version=1.0.0&identifier=all&language=fr-CA')
 
@@ -223,7 +246,7 @@ class DescribeProcessTranslationsTest(unittest.TestCase):
         assert output_abstracts == ["Description", "Description"]
 
 
-class DescribeProcessInputTest(unittest.TestCase):
+class DescribeProcessInputTest(TestBase):
 
     def describe_process(self, process):
         client = client_for(Service(processes=[process]))
@@ -244,7 +267,7 @@ class DescribeProcessInputTest(unittest.TestCase):
                 Metadata('process metadata 2', 'http://example.org/2')]
         )
         result = self.describe_process(hello_process)
-        assert result.inputs == [('the_name', 'literal', 'string', None)]
+        assert result.inputs == [('the_name', 'literal', 'string', None, None)]
         assert result.metadata == ['process metadata 1', 'process metadata 2']
 
     def test_one_literal_integer_input(self):
@@ -256,7 +279,33 @@ class DescribeProcessInputTest(unittest.TestCase):
                                                      'Input number',
                                                      data_type='positiveInteger')])
         result = self.describe_process(hello_process)
-        assert result.inputs == [('the_number', 'literal', 'positiveInteger', None)]
+        assert result.inputs == [('the_number', 'literal', 'positiveInteger', None, None)]
+
+    def test_multi_uoms_literal_float_input(self):
+        def hello(request):
+            pass
+        hello_process = Process(hello, 'hello',
+                                'Process Hello',
+                                inputs=[LiteralInput('the_number',
+                                                     'Input number',
+                                                     data_type='float',
+                                                     uoms=[
+                                                         'metre',
+                                                         'feet',
+                                                         'undef',
+                                                         UOM('pixel', 'http://schema.com/#pixel'),
+                                                     ])])
+        result = self.describe_process(hello_process)
+        uoms = {
+            'default': {'uom': 'metre', 'reference': OGCUNIT['metre']},
+            'supported': [
+                {'uom': 'metre', 'reference': OGCUNIT['metre']},
+                {'uom': 'feet', 'reference': OGCUNIT['feet']},
+                {'uom': 'undef', 'reference': None},  # no mapping to known OGC URN
+                {'uom': 'pixel', 'reference': 'http://schema.com/#pixel'},
+            ]
+        }
+        assert result.inputs == [('the_number', 'literal', 'float', None, uoms)]
 
     def test_one_literal_integer_default_zero(self):
         def hello(request):
@@ -268,10 +317,10 @@ class DescribeProcessInputTest(unittest.TestCase):
                                                      data_type='integer',
                                                      default=0)])
         result = self.describe_process(hello_process)
-        assert result.inputs == [('the_number', 'literal', 'integer', "0")]
+        assert result.inputs == [('the_number', 'literal', 'integer', "0", None)]
 
 
-class InputDescriptionTest(unittest.TestCase):
+class InputDescriptionTest(TestBase):
 
     def test_literal_integer_input(self):
         literal = LiteralInput('foo', 'Literal foo', data_type='positiveInteger',
@@ -287,7 +336,7 @@ class InputDescriptionTest(unittest.TestCase):
             'foo',
             'Foo',
             data_type='integer',
-            uoms=['metre'],
+            uoms=['metre', 'feet'],
             allowed_values=(
                 1, 2, (5, 10), (12, 4, 24),
                 AllowedValue(
@@ -301,6 +350,9 @@ class InputDescriptionTest(unittest.TestCase):
         assert len(data["allowed_values"]) == 5
         assert data["allowed_values"][0]["value"] == 1
         assert data["allowed_values"][0]["range_closure"] == "closed"
+        assert data["uom"] == {"uom": "metre", "reference": OGCUNIT["metre"]}
+        assert data["uoms"][0] == {"uom": "metre", "reference": OGCUNIT["metre"]}
+        assert data["uoms"][1] == {"uom": "feet", "reference": OGCUNIT["feet"]}
 
     def test_complex_input_identifier(self):
         complex_in = ComplexInput('foo', 'Complex foo', keywords=['kw1', 'kw2'], supported_formats=[Format('bar/baz')])
@@ -334,7 +386,7 @@ class InputDescriptionTest(unittest.TestCase):
         assert data["dimensions"] == 2
 
 
-class OutputDescriptionTest(unittest.TestCase):
+class OutputDescriptionTest(TestBase):
 
     @pytest.mark.skip(reason="not working")
     def test_literal_output(self):
@@ -395,6 +447,8 @@ class OutputDescriptionTest(unittest.TestCase):
 
 
 def load_tests(loader=None, tests=None, pattern=None):
+    import unittest
+
     if not loader:
         loader = unittest.TestLoader()
     suite_list = [
